==> huaweicloudsdkcbr-3.0.53-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/show_op_log_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowOpLogResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'operation_log': 'OperationLog'
    }

    attribute_map = {
        'operation_log': 'operation_log'
    }

    def __init__(self, operation_log=None):
        """ShowOpLogResponse - a model defined in huaweicloud sdk"""
        
        super(ShowOpLogResponse, self).__init__()

        self._operation_log = None
        self.discriminator = None

        if operation_log is not None:
            self.operation_log = operation_log

    @property
    def operation_log(self):
        """Gets the operation_log of this ShowOpLogResponse.


        :return: The operation_log of this ShowOpLogResponse.
        :rtype: OperationLog
        """
        return self._operation_log

    @operation_log.setter
    def operation_log(self, operation_log):
        """Sets the operation_log of this ShowOpLogResponse.


        :param operation_log: The operation_log of this ShowOpLogResponse.
        :type: OperationLog
        """
        self._operation_log = operation_log

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowOpLogResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcbr-3.0.69-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/show_op_log_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowOpLogResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'operation_log': 'OperationLog'
    }

    attribute_map = {
        'operation_log': 'operation_log'
    }

    def __init__(self, operation_log=None):
        """ShowOpLogResponse - a model defined in huaweicloud sdk"""
        
        super(ShowOpLogResponse, self).__init__()

        self._operation_log = None
        self.discriminator = None

        if operation_log is not None:
            self.operation_log = operation_log

    @property
    def operation_log(self):
        """Gets the operation_log of this ShowOpLogResponse.


        :return: The operation_log of this ShowOpLogResponse.
        :rtype: OperationLog
        """
        return self._operation_log

    @operation_log.setter
    def operation_log(self, operation_log):
        """Sets the operation_log of this ShowOpLogResponse.


        :param operation_log: The operation_log of this ShowOpLogResponse.
        :type: OperationLog
        """
        self._operation_log = operation_log

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowOpLogResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
